@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook Kontact Plugin.
 
-  Copyright (c) 2009-2016 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ EXPORT_KONTACT_PLUGIN(KAddressBookPlugin, kaddressbook)
 KAddressBookPlugin::KAddressBookPlugin(KontactInterface::Core *core, const QVariantList &)
     : KontactInterface::Plugin(core, core, "kaddressbook")
 {
-    setComponentName(QStringLiteral("kaddressbook"), QStringLiteral("kaddressbook"));
+    setComponentName(QStringLiteral("kaddressbook"), i18n("KAddressBook"));
 
     QAction *action =
         new QAction(QIcon::fromTheme(QStringLiteral("contact-new")),
@@ -111,7 +111,7 @@ KParts::ReadOnlyPart *KAddressBookPlugin::createPart()
 {
     KParts::ReadOnlyPart *part = loadPart();
     if (!part) {
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     // disable the Ctrl+N shortcut, as it is used by Kontact already
